@@ -17,6 +17,7 @@ function createTranslations() {
         'ConstraintError': gettext('The security token (FIDO 2) does not meet required criteria.'),
         'NotAllowedError': gettext('Something went wrong, or the time limit was reached. Please, try it again.'),
         'NoAuthenticatorsError': gettext('No compatible security keys are registered in your account.'),
+        'InvalidStateError': gettext('An attempt was made to use a security key that is not registered in your account'),
     }
     TRANSLATIONS.GENERIC_ERROR_MESSAGE = gettext('An unknown error has occurred.')
     TRANSLATIONS.FIDO2_NOT_AVAILABLE = gettext('FIDO 2 is not available. Your browser may not support it'
@@ -210,4 +211,5 @@ export {
     fido2ErrorResponseCallback,
     sendFido2RegistrationRequest,
     startFido2,
+    createTranslations,
 }
